==> sphinxcontrib-drawio-0.0.14.tar.gz: sphinxcontrib-drawio-0.0.14/tests/test_options.py <==
from pathlib import Path
from typing import List

import pytest

from bs4 import Tag
from sphinx.application import Sphinx
from sphinx.util.images import get_image_size
from sphinxcontrib.drawio import DrawIOError


# deprecated drawio directive test
@pytest.mark.sphinx("html", testroot="simple")
def test_simple(directives: List[Tag]):
    assert (
        directives[0].decode()
        == '<img alt="_images/drawio-bf0f85b68784bab0e62bf5902f5a46b65d71ee70.png" '
        'class="drawio" src="_images/drawio-bf0f85b68784bab0e62bf5902f5a46b65d71ee70.png'
        '"/>'
    )


@pytest.mark.sphinx("html", testroot="page-index")
def test_page_index(images: List[Path]):
    assert images[0].name == "pages.png"
    assert images[1].name == "pages1.png"
    assert images[2].name == "pages2.png"
    assert images[3].name == "pages.png"
    assert get_image_size(images[0]) == (125, 64)
    assert get_image_size(images[1]) == (65, 64)
    assert get_image_size(images[2]) == (65, 64)
    assert get_image_size(images[3]) == (125, 64)

    # deprecated drawio directive
    assert images[4].name == "drawio-23596e9713a51f864e734695324de3c19e930125.png"
    assert images[5].name == "drawio-d890782f09bf6478d353265d5894253de5fefbd3.png"
    assert images[6].name == "drawio-4d4e2f8704b20c01096eed9b97cd6588d479f3a6.png"
    assert images[7].name == "drawio-23596e9713a51f864e734695324de3c19e930125.png"
    assert get_image_size(images[4]) == (125, 64)
    assert get_image_size(images[5]) == (65, 64)
    assert get_image_size(images[6]) == (65, 64)
    assert get_image_size(images[7]) == (125, 64)


@pytest.mark.sphinx("html", testroot="alt")
def test_alt(directives: List[Tag]):
    assert directives[0]["alt"] == "An Example"

    # deprecated drawio directive
    assert directives[1]["alt"] == "An Example"


@pytest.mark.sphinx("html", testroot="align")
def test_align(directives: List[Tag]):
    assert "align-left" in directives[0]["class"]
    assert "align-center" in directives[1]["class"]
    assert "align-right" in directives[2]["class"]

    # deprecated drawio directive
    assert directives[3].parent.parent["align"] == "left"
    assert directives[4].parent.parent["align"] == "center"
    assert directives[5].parent.parent["align"] == "right"


# noinspection PyTypeChecker
@pytest.mark.sphinx("html", testroot="width-height")
def test_width_height(images: List[Path]):

    assert get_image_size(images[0])[0] == 100
    assert get_image_size(images[1])[1] == 100
    assert get_image_size(images[2])[0] == 1000

    # deprecated drawio directive
    assert get_image_size(images[3])[0] == 100
    assert get_image_size(images[4])[1] == 100
    assert get_image_size(images[5])[0] == 1000


# noinspection PyTypeChecker
@pytest.mark.sphinx("html", testroot="scale")
def test_scale(images: List[Path]):

    # actual image size is 124x63
    assert get_image_size(images[0]) == (245, 124)
    assert get_image_size(images[1]) == (1217, 616)
    assert get_image_size(images[2]) == (64, 33)
    assert get_image_size(images[3]) == (125, 64)
    assert get_image_size(images[4]) == (610, 309)

    # deprecated drawio directive
    assert get_image_size(images[5]) == (245, 124)
    assert get_image_size(images[6]) == (1217, 616)
    assert get_image_size(images[7]) == (610, 309)


@pytest.mark.sphinx("html", testroot="transparency")
def test_transparency():
    pass


@pytest.mark.sphinx("html", testroot="image")
def test_image(directives: List[Tag]):
    (img,) = directives
    assert img.name == "img"
    assert img["src"] == "_images/box.svg"
    assert img["alt"] == "_images/box.svg"
    assert img["class"] == ["drawio"]


@pytest.mark.sphinx("html", testroot="figure")
def test_figure(content: Sphinx, directives: List[Tag]):
    filenames_sizes = [
        ("box.png", (125, 64)),
        ("box1.png", (185, 94)),
    ]
    for img, (filename, size) in zip(directives, filenames_sizes):
        assert img.name == "img"
        assert img["src"] == "_images/" + filename
        assert img["alt"] == "_images/" + filename
        assert img["class"] == ["drawio"]
        image_path = content.outdir / img["src"]
        assert get_image_size(image_path) == size
        imageContainerTag = img.parent
        assert imageContainerTag.name == "figure"


@pytest.mark.sphinx("html", testroot="reference")
def test_reference(directives: List[Tag]):
    (img,) = directives
    assert img.name == "img"
    assert img["src"] == "_images/box.svg"
    assert img["alt"] == "_images/box.svg"
    assert img["class"] == ["drawio"]


@pytest.mark.sphinx("html", testroot="warnings")
def test_warnings(content: Sphinx, directives: List[Tag]):
    assert len(directives) == 1
    warnings = content._warning.getvalue()
    assert "1 argument(s) required, 0 supplied" in warnings
    assert "image file not readable: missing.drawio" in warnings
    assert '"gif" unknown; choose from "png", "jpg", "svg", or "pdf".' in warnings


@pytest.mark.sphinx("html", testroot="bad-config")
def test_bad_config(app_with_local_user_config):
    with pytest.raises(DrawIOError) as exc:
        app_with_local_user_config.build()
    (message,) = exc.value.args
    assert message == "Invalid export format 'bmp' specified for builder 'html'"

==> sphinxcontrib-drawio-0.0.17.tar.gz: sphinxcontrib-drawio-0.0.17/tests/test_options.py <==
from pathlib import Path
from typing import List

import pytest

from bs4 import Tag
from sphinx.application import Sphinx
from sphinx.util.images import get_image_size
from sphinxcontrib.drawio import DrawIOError


@pytest.mark.sphinx("html", testroot="page-index")
def test_page_index(images: List[Path]):
    assert images[0].name == "pages.png"
    assert images[1].name == "pages1.png"
    assert images[2].name == "pages2.png"
    assert images[3].name == "pages.png"
    assert get_image_size(images[0]) == (125, 65)
    assert get_image_size(images[1]) == (65, 65)
    assert get_image_size(images[2]) == (65, 65)
    assert get_image_size(images[3]) == (125, 65)


@pytest.mark.sphinx("html", testroot="page-index-out-of-range")
def test_page_index_out_of_range(content: Sphinx, directives: List[Tag]):
    assert len(directives) == 1

    warnings = content._warning.getvalue()
    assert "selected page 6 is out of range [0,5]" in warnings


@pytest.mark.sphinx("html", testroot="page-name")
def test_page_name(images: List[Path]):
    assert images[0].name == "pages.png"
    assert images[1].name == "pages1.png"
    assert get_image_size(images[0]) == (125, 65)
    assert get_image_size(images[1]) == (65, 65)


@pytest.mark.sphinx("html", testroot="alt")
def test_alt(directives: List[Tag]):
    assert directives[0]["alt"] == "An Example"


@pytest.mark.sphinx("html", testroot="align")
def test_align(directives: List[Tag]):
    assert "align-left" in directives[0]["class"]
    assert "align-center" in directives[1]["class"]
    assert "align-right" in directives[2]["class"]


# noinspection PyTypeChecker
@pytest.mark.sphinx("html", testroot="width-height")
def test_width_height(images: List[Path]):
    assert get_image_size(images[0])[0] == 100
    assert get_image_size(images[1])[1] == 100
    assert get_image_size(images[2])[0] == 1000


# noinspection PyTypeChecker
@pytest.mark.sphinx("html", testroot="scale")
def test_scale(images: List[Path]):
    # image size by default is 125x65. the scaling isn't perfect
    assert get_image_size(images[0]) == (245, 125)
    assert get_image_size(images[1]) == (1217, 617)
    assert get_image_size(images[2]) == (64, 34)
    assert get_image_size(images[3]) == (125, 65)
    assert get_image_size(images[4]) == (610, 310)


@pytest.mark.skip(reason="No actual test case")
@pytest.mark.sphinx("html", testroot="transparency")
def test_transparency():
    pass


@pytest.mark.sphinx("html", testroot="image")
def test_image(directives: List[Tag]):
    (img,) = directives
    assert img.name == "img"
    assert img["src"] == "_images/box.svg"
    assert img["alt"] == "_images/box.svg"
    assert img["class"] == ["drawio"]


@pytest.mark.sphinx("html", testroot="figure")
def test_figure(content: Sphinx, directives: List[Tag]):
    filenames_sizes = [
        ("box.png", (125, 65)),
        ("box1.png", (185, 95)),
    ]
    for img, (filename, size) in zip(directives, filenames_sizes):
        assert img.name == "img"
        assert img["src"] == "_images/" + filename
        assert img["alt"] == "_images/" + filename
        assert img["class"] == ["drawio"]
        image_path = content.outdir / img["src"]
        assert get_image_size(image_path) == size
        imageContainerTag = img.parent
        assert imageContainerTag.name == "figure"


@pytest.mark.sphinx("html", testroot="reference")
def test_reference(directives: List[Tag]):
    (img,) = directives
    assert img.name == "img"
    assert img["src"] == "_images/box.svg"
    assert img["alt"] == "_images/box.svg"
    assert img["class"] == ["drawio"]


@pytest.mark.sphinx("html", testroot="warnings")
def test_warnings(content: Sphinx, directives: List[Tag]):
    assert len(directives) == 1
    warnings = content._warning.getvalue()
    assert "1 argument(s) required, 0 supplied" in warnings
    assert "image file not readable: missing.drawio" in warnings
    assert '"gif" unknown; choose from "png", "jpg", "svg", or "pdf".' in warnings


@pytest.mark.sphinx("html", testroot="bad-config")
def test_bad_config(app_with_local_user_config):
    with pytest.raises(DrawIOError) as exc:
        app_with_local_user_config.build()
    (message,) = exc.value.args
    assert message == "export format 'bmp' is unsupported by draw.io"


@pytest.mark.sphinx("html", testroot="bad-config2")
def test_bad_config2(app_with_local_user_config):
    with pytest.raises(DrawIOError) as exc:
        app_with_local_user_config.build()
    (message,) = exc.value.args
    assert message == "invalid export format 'pdf' specified for builder 'html'"


@pytest.mark.sphinx("html", testroot="page-name-not-exist")
def test_page_name_not_exist_config(app_with_local_user_config):
    with pytest.raises(DrawIOError) as exc:
        app_with_local_user_config.build()
    (message,) = exc.value.args
    assert "has no diagram named: none existed page name" in message


@pytest.mark.sphinx("html", testroot="page-name-and-page-index")
def test_page_name_and_page_index_config(app_with_local_user_config):
    with pytest.raises(DrawIOError) as exc:
        app_with_local_user_config.build()
    (message,) = exc.value.args
    assert message == "page-name & page-index cannot coexist"
